@@ -76,6 +76,7 @@ LOG_FILE=DATA_FILE_PATH+"maebo.log"
 DATA_DB_FILE=DATA_FILE_PATH+"maebo_data.db"
 WEBSITE_DB_FILE=INSTALL_PATH+"maebo_w.db"
 DEFAULT_AVATAR_FILE=ICONS_DIR+"default_avatar.jpg"
+VERIFIED_FILE=ICONS_DIR+"verified.png"
 
 COLOR_BACKGROUND="#edf1f2"
 COLOR_BACKGROUND_ALT="#e6eaeb"
@@ -83,9 +84,12 @@ COLOR_BACKGROUND_ALT="#e6eaeb"
 ROLE_AVATAR=99
 ROLE_TIME=98
 ROLE_NAME=97
+ROLE_ISVERIFIED=85
+ROLE_SCREENNAME=87
 ROLE_THUMBNAIL=96
 ROLE_RT_TEXT=95
 ROLE_RT_NAME=94
+ROLE_RT_SCREENNAME=86
 ROLE_RT_AVATAR=93
 ROLE_ID=92
 ROLE_RT_THUMBNAIL=91
@@ -290,13 +294,29 @@ def build_a_status_from_obj(obj,accountId):
     result["user"]=user
     result["author"]=user
     result["if_rt"]=False
+    
+    # FUck SInA ApI!!!
+    
+    #print "Debug!"
+    #dump(obj)
+    #print "============================"
+    #dump(getattr(obj,"parse"))
+    
+    #result["if_dm"]=getattr(obj,"status")["id"]
+    #print "FucK SinA"
+    #print result["if_dm"]
+    
     rt=result["retweeted_status"]
     if rt!=None:
         rtStatus=build_a_status_from_obj(rt,accountId)
         rtStatus["if_rt"]=True
         result["retweeted_status"]=rtStatus
     return result
-
+    
+def dump(obj):
+    for attr in dir(obj):
+        print "obj.%s = %s" % (attr, getattr(obj, attr))
+    
 def build_a_user_from_obj(obj,accountId):
     result = {}
     for att in USER_ATT_NAMES:
